@@ -11,6 +11,7 @@ class Bills(ApiBase):
     GET_BILLS = '/query?query=select * from Bill STARTPOSITION {0} MAXRESULTS 1000'
     POST_BILL = '/bill?minorversion=38'
     DELETE_BILL = '/bill?operation=delete'
+    GET_BILL_BY_ID = '/bill/{0}'
 
     def get(self):
         """
@@ -38,3 +39,11 @@ class Bills(ApiBase):
             'SyncToken': '1'
         }
         return self._post_request(data, Bills.DELETE_BILL)
+
+    def get_by_id(self, bill_id):
+        """
+        Get Bill from Quickbooks Online
+        :param bill_id: Bill Id
+        :return: Dict Response
+        """
+        return self._get_request('Bill', Bills.GET_BILL_BY_ID.format(bill_id))
